/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 27/06/22.
//

#ifndef FGGL_AUDIO_NULL_AUDIO_HPP
#define FGGL_AUDIO_NULL_AUDIO_HPP

#include "fggl/audio/audio.hpp"

namespace fggl::audio {

	class NullAudioService : public AudioService {
		public:
			NullAudioService() = default;
			~NullAudioService() override = default;

			NullAudioService(NullAudioService&) = delete;
			NullAudioService(NullAudioService&&) = delete;
			NullAudioService& operator=(const NullAudioService&) = delete;
			NullAudioService& operator=(NullAudioService&&) = delete;

			void play(const std::string & /*filename*/, bool /*looping = false*/) override;
			void play(const AudioClipShort & /*clip*/, bool /*looping = false*/) override;
	};

	struct NullAudio {
		constexpr static const char *name = "fggl::audio::NULL";
		constexpr static const std::array<modules::ServiceName, 1> provides = {
			SERVICE_AUDIO_PLAYBACK
		};
		constexpr static const std::array<modules::ServiceName, 0> depends = {};
		bool factory(modules::ServiceName, modules::Services&);
	};


} // namespace fggl::audio

#endif //FGGL_AUDIO_NULL_AUDIO_HPP
