/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 27/06/22.
//

#ifndef FGGL_GFX_INTERFACES_HPP
#define FGGL_GFX_INTERFACES_HPP

#include "fggl/gfx/paint.hpp"
#include "fggl/entity/entity.hpp"
#include "fggl/modules/module.hpp"

namespace fggl::gfx {

	struct Bounds {
		float top;
		float right;
		float bottom;
		float left;
	};

	class Graphics {
		public:
			constexpr static const auto service = modules::make_service("fggl::gfx::Graphics");

			virtual ~Graphics() = default;
			virtual void clear() = 0;
			virtual void resize(int width, int height) = 0;

			virtual Bounds canvasBounds() = 0;
			virtual void draw2D(const Paint &paint) = 0;

			virtual void drawScene(entity::EntityManager &, bool debugMode = false) = 0;
	};

} // namespace fggl::gfx

#endif //FGGL_GFX_INTERFACES_HPP
